from django.test import TestCase

from .models import ImportTask, generate_file_path


class ImportTest(TestCase):
    def test_csv_import(self):
        pass

    def test_generate_file_path(self):
        self.assertEqual(generate_file_path(ImportTask(), "allo.csv"), "csv_imports/allo.csv")
        self.assertEqual(generate_file_path(ImportTask(), "allo.xlsx"), "csv_imports/allo.xlsx")
        self.assertEqual(generate_file_path(ImportTask(), "allo.foo.bar"), "csv_imports/allo.foo.bar")

        long_name = "foo" * 100

        test_file_name = "%s.xls.csv" % long_name
        self.assertEqual(len(generate_file_path(ImportTask(), test_file_name)), 100)
        self.assertEqual(generate_file_path(ImportTask(), test_file_name), "csv_imports/%s.csv" % long_name[:84])

        test_file_name = "%s.abc.xlsx" % long_name
        self.assertEqual(len(generate_file_path(ImportTask(), test_file_name)), 100)
        self.assertEqual(generate_file_path(ImportTask(), test_file_name), "csv_imports/%s.xlsx" % long_name[:83])



# Generated by Django 2.2.17 on 2021-02-19 15:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("users", "0002_remove_failed_logins"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="failedlogin",
            name="user",
        ),
        migrations.AddField(
            model_name="failedlogin",
            name="username",
            field=models.CharField(default=None, max_length=256),
            preserve_default=False,
        ),
    ]



from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("csv_imports", "0002_auto_20161118_1920"),
    ]

    operations = [
        migrations.AddField(
            model_name="importtask",
            name="task_status",
            field=models.CharField(default="PENDING", max_length=32),
        ),
    ]



# Generated by Django 5.0.3 on 2024-06-13 18:36

import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("users", "0003_auto_20210219_1548"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterField(
            model_name="failedlogin",
            name="failed_on",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="passwordhistory",
            name="password",
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name="passwordhistory",
            name="set_on",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="passwordhistory",
            name="user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                related_name="password_history",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AlterField(
            model_name="recoverytoken",
            name="created_on",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="recoverytoken",
            name="token",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name="recoverytoken",
            name="user",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT, related_name="recovery_tokens", to=settings.AUTH_USER_MODEL
            ),
        ),
    ]



from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="FailedLogin",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True)),
                ("failed_on", models.DateTimeField(auto_now_add=True)),
                ("user", models.ForeignKey(to=settings.AUTH_USER_MODEL, on_delete=models.PROTECT)),
            ],
        ),
        migrations.CreateModel(
            name="PasswordHistory",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True)),
                ("password", models.CharField(help_text="The hash of the password that was set", max_length=255)),
                ("set_on", models.DateTimeField(help_text="When the password was set", auto_now_add=True)),
                (
                    "user",
                    models.ForeignKey(
                        help_text="The user that set a password", on_delete=models.PROTECT, to=settings.AUTH_USER_MODEL
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="RecoveryToken",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True)),
                (
                    "token",
                    models.CharField(default=None, help_text="token to reset password", unique=True, max_length=32),
                ),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("user", models.ForeignKey(to=settings.AUTH_USER_MODEL, on_delete=models.PROTECT)),
            ],
        ),
    ]
